@@ -8,7 +8,7 @@ use Devel::hdb::TraceFollow;
 use IO::Socket::INET;
 use IO::File;
 
-our $VERSION = 0.21001;
+our $VERSION = 0.23;
 
 sub import {
     my $class = shift;
@@ -149,20 +149,28 @@ currently executing line.
 Hover the mouse over a variable to see its value.  It shows the value in
 whichever stack frame is being displayed.  To see the values for variables
 in higher frames, select the appropriate frame from the tab on the left.
+Right-click on a variable to add it to the list of watch expressions on the
+right.
 
 =head3 Watch Expressions
 
 The right side of the GUI shows watch expressions.  To add a new expression to
-the watch window, click on the "+".  To remove a watched expression, click on
-the "x" next to its name.  Composite types like hashes and arrays have a blue
-circled number indicating how many elements belong to it.  To collapse/expand
-them, click the blue circle.
+the watch window, click on the "+" or right-click on a variable in a code pane.
+To remove a watched expression, click on the "x" next to its name.  Composite
+types like hashes and arrays have a blue circled number indicating how many
+elements belong to it.  To collapse/expand them, click the blue circle.
 
 A watched typeglob will show all the used slots within the glob.  Older
 versions of perl will always create an undefined value in the SCALAR slot.
 The value for the IO slot will be the file descriptor number of the
 filehandle and its position as reported by sysseek(), or undef if it is closed.
 
+Enabling the checkbox next to the expression turns it into a watchpoint.
+Watchpoints are evaluated in list context, and if their value changes, the
+debugged program will stop.  For list values, it is considered changed if any
+of the elements changes value or if the number of values in the list changes.
+It will not perform a deep search for changed values.
+
 =head3 Key bindings
 
 The debugger responds to these keys, which are generally the same as the
@@ -203,9 +211,11 @@ debugger window, it will pop up a dialog with two options
 =over
 
 =item Open
+
 Open a new browser window and debug the child process inside it
 
 =item Detach
+
 Disables the debugger in the child process, and forces it to run to completion.
 
 =back
