@@ -1,6 +1,7 @@
 function Debugger(sel) {
     var dbg = this;
     var $elt = this.$elt = $(sel);
+    var perlVarPopoverDelay = 400;  // Time in ms the mouse has to rest over a variable before it gets the value
 
     this.filewindowDiv = $elt.find('div#filewindow');
     this.stackDiv = $elt.find('div#stack');
@@ -35,10 +36,14 @@ function Debugger(sel) {
     function whenStackTabIsShown($elt, cb) {
         var stackId = $elt.closest('.tab-pane').attr('id'),
             relatedTab = $('#stack-tabs a[href="#'+stackId+'"]');
-        relatedTab.one('shown', function(e) {
-            // relatedTarget is true when the anchor was actually clicked?
-            // seems to be undefined during mouseover of the anchor
+        relatedTab.on('shown.whenStackTabIsShown', function(e) {
+            // This cb is fired both when the active tab is switched, and during
+            // mouseover of the tab - the latter may be a bug in Bootstrap
+            // relatedTarget is true when the anchor was actually clicked, and
+            // refers to what was previously the active tab.
+            // relatedTarget is undefined during mouseover of the anchor
             if (e.relatedTarget) {
+                relatedTab.off('shown.whenStackTabIsShown');
                 cb();
             }
         });
@@ -121,8 +126,8 @@ function Debugger(sel) {
                         is_string_eval: is_string_eval,
                         wantarray: frame_obj.sigil,
                         active: $tabs.children().length == 0
-                    }));
-            var $tab_link = $tab.find('a[rel="tooltip"]').tooltip();
+                    }))
+                    .tooltip();
 
             $codePane = $( this.templates.navPane({
                                 serial: frame_obj.serial,
@@ -136,7 +141,7 @@ function Debugger(sel) {
             setElementHeight.call($codePane.find('.managed-height'));
 
             var needs_args = 1;
-            $tab_link.on('click', function() {
+            $tab.find('a').on('click', function() {
                 if (needs_args) {
                     needs_args = 0;
 
@@ -297,10 +302,11 @@ function Debugger(sel) {
     };
 
     this.handleControlButtonResponse = function(response) {
-        var events = [];
+        var events = [],
+            watchedExpressionManager = this.watchedExpressionManager;
         if (response.events) {
             events = response.events.map(function(event) {
-                return new ProgramEvent(event);
+                return new ProgramEvent(event, watchedExpressionManager);
             });
         }
 
@@ -370,7 +376,7 @@ function Debugger(sel) {
         var also = $elt.attr('data-part-of');
         if (also) {
             // hilite it, too
-            $elt.parent().find('[data-eval="'+also+'"]').addClass('hovered-perl-var');
+            $elt.siblings('[data-eval="'+also+'"]').addClass('hovered-perl-var');
         }
         $perlVarPopover = $elt;
 
@@ -381,25 +387,40 @@ function Debugger(sel) {
                 restInterface.getVarAtLevel(eval, stack_level)
                              .done(function(data) { drawPerlPopover(data, $elt) });
             }
-        }, 400);
+        }, perlVarPopoverDelay);
         $perlVarPopover.data('timerid', timer);
     }
 
     function removePopoverPerlVar (e) {
-        $(e.target).removeClass('hovered-perl-var');
+        var $target = $(e.target),
+            part_of = $target.attr('data-part-of');
+
+        if (part_of !== undefined) {
+            $target = $target.add('[data-eval="'+part_of+'"]');
+        }
+
+        $target.removeClass('hovered-perl-var');
         if ($perlVarPopover) {
             $perlVarPopover.popover('destroy');
             $perlVarPopover = undefined;
         }
     }
 
+    function addPerlVarToWatchExpressions(e) {
+        var $target = $(e.target),
+            expr = $target.attr('data-eval');
+
+        e.preventDefault();
+        this.watchedExpressionManager.addExpression(expr, false);
+    }
+
     var $lastControlKeyElement = $control_buttons.filter('[data-action="stepin"]');
     function setKeybindings() {
         // Seems that divs can't receive key events, so we can't bind the
         // handler to this.elt :(
         $(document).keypress(function(e) {
-            if (! $(e.target).is('body')) {
-                // Don't handle events for elements like text inputs
+            if ($(e.target).closest('form').length) {
+                // Don't handle events for elements like text inputs inside forms
                 return;
             }
             if (e.ctrlKey || e.altKey || e.metaKey) {
@@ -655,13 +676,15 @@ function Debugger(sel) {
     // Initialization
     this.restInterface.programName()
         .done(function(program_name) {
-            $elt.find('li#program-name a').html(program_name);
+            $elt.find('li#program-name a').html(program_name)
+                                          .attr('title', program_name);
             dbg.programName = program_name;
         });
     this.fileManager = new FileManager(this.restInterface);
 
     this.breakpointManager = new BreakpointManager(this.$elt, this.restInterface);
     this.watchedExpressionManager = new WatchedExprManager(this.restInterface);
+    this.watchedExpressionManager.loadWatchpoints();
 
     this.stackManager = new StackManager(this.restInterface);
     this.stackManager.initialize()
@@ -675,6 +698,7 @@ function Debugger(sel) {
     $elt.on('click', '.control-button[disabled!="disabled"]', this.controlButtonClicked.bind(this))
         .on('mouseenter', '.popup-perl-var', popoverPerlVar.bind(this))
         .on('mouseleave', '.popup-perl-var', removePopoverPerlVar.bind(this))
+        .on('contextmenu', '.popup-perl-var', addPerlVarToWatchExpressions.bind(this))
         .on('click', '.current-sub-and-args', setCurrentLineForCodeTableEvent.bind(this))
         .on('hangup', notifyProgramHasCompletelyExited.bind(this))
         .on('click', '#add-file', pickFileToLoad.bind(this))
