@@ -153,7 +153,13 @@ PerlValue.GLOB = function(value) {
     this.value = {};
     var k;
     for (k in value.__value) {
-        if (value.__value.hasOwnProperty(k)) {
+        if (k === 'PACKAGE') {
+            this.pkg = value.__value[k];
+        } else if (k === 'NAME') {
+            this.name = value.__value[k];
+        } else if (k === 'IOseek') {
+            this.ioseek = value.__value[k];
+        } else if (value.__value.hasOwnProperty(k)) {
             this.value[k] = PerlValue.parseFromEval(value.__value[k]);
         }
     }
@@ -172,9 +178,12 @@ PerlValue.GLOB.prototype.renderValue = function(view) {
 
     var html = '<dl class="PerlValue">',
         k;
+    html += '<dt><span class="label">Name</span></dt><dd><span><b>' + this.pkg + '</b>::' + this.name + '</span></dd>';
     for (k in this.value) {
+        var rendered = this.value[k].render(view);
         html += '<dt><span class="label label-success">' + k + '</span></dt><dd>'
-                + this.value[k].render(view) + '</dd>';
+                + ( k === 'IO' ? rendered + ' @ ' + this.ioseek : rendered )
+                + '</dd>';
     }
     return html + '</dl>';
 }
@@ -216,7 +225,10 @@ PerlValue.REGEXP = function(value) {
 }
 PerlValue.REGEXP.prototype = new PerlValue();
 PerlValue.REGEXP.prototype.renderValue = function(view) {
-    return '<span class="PerlValue">' + this.escapedValue() + '</span>';
+    return '<span class="PerlValue">m/'
+            + this.escapedValue(this.value[0])
+            + '/' + this.escapedValue(this.value[1])
+            + '</span>';
 }
 
 
